#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ieee754
version:              0.8.0
visibility:           public
id:                   ieee754-0.8.0-CHSaaJtgXtAIvy6hnwP5XY
key:                  ieee754-0.8.0-CHSaaJtgXtAIvy6hnwP5XY
license:              BSD-3-Clause
copyright:            (c) 2011-2016. Patrick Perry <patperry@gmail.com>
maintainer:           Patrick Perry <patperry@gmail.com>
author:               Patrick Perry
homepage:             http://github.com/patperry/hs-ieee754
synopsis:             Utilities for dealing with IEEE floating point numbers
description:
    Utilities for dealing with IEEE floating point numbers, ported
    from the Tango math library; approximate and exact equality
    comparisons for general types.

category:             Math
abi:                  f889f1055e2bc4289cab7a74d4d4e877
exposed:              True
exposed-modules:      Data.AEq Numeric.IEEE
import-dirs:          /usr/lib/ghc-8.10.5/site-local/ieee754-0.8.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/ieee754-0.8.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/ieee754-0.8.0
hs-libraries:         HSieee754-0.8.0-CHSaaJtgXtAIvy6hnwP5XY
depends:              base-4.14.2.0
haddock-interfaces:   /usr/share/doc/haskell-ieee754/html/ieee754.haddock
haddock-html:         /usr/share/doc/haskell-ieee754/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

